@@ -3,7 +3,7 @@ package Nmap::Parser;
 use strict;
 use XML::Twig;
 
-our $VERSION = 1.31;
+our $VERSION = 1.32;
 
 
 sub new {
@@ -624,7 +624,7 @@ sub __host_trace_error_tag_hdlr {
 
         my $error_tag = $trace_tag->first_child('error');
         if ( defined $error_tag ) {
-            
+
             # If an error happens, always provide a true value even if
             # it doesn't contains a useful string
             my $errorstr = $error_tag->{att}->{errorstr} || 1;
@@ -1103,35 +1103,35 @@ Nmap::Parser - parse nmap scan data with perl
 
   use Nmap::Parser;
   my $np = new Nmap::Parser;
-  
+
   $np->parsescan($nmap_path, $nmap_args, @ips);
     #or
   $np->parsefile($file_xml);
-  
+
   my $session    = $np->get_session();
     #a Nmap::Parser::Session object
-    
+
   my $host       = $np->get_host($ip_addr);
     #a Nmap::Parser::Host object
-    
+
   my $service = $host->tcp_service(80);
     #a Nmap::Parser::Host::Service object
-    
+
   my $os         = $host->os_sig();
     #a Nmap::Parser::Host::OS object
- 
+
  #---------------------------------------
- 
+
  my $np2 = new Nmap::Parser;
- 
+
  $np2->callback(\&my_callback);
- 
+
  $np2->parsefile($file_xml);
     #or
  $np2->parsescan($nmap_path, $nmap_args, @ips);
-    
+
  sub my_callback {
- 
+
    my $host = shift;
     #Nmap::Parser::Host object
     #.. see documentation for all methods ...
@@ -1140,6 +1140,7 @@ Nmap::Parser - parse nmap scan data with perl
 
 
 I<For a full listing of methods see the documentation corresponding to each object.>
+You can also visit the website L<https://modernistik.github.io/Nmap-Parser/> for additional installation instructions.
 
 =head1 DESCRIPTION
 
@@ -1148,7 +1149,7 @@ It is implemented by parsing the xml scan data that is generated by nmap. This
 will enable anyone who utilizes nmap to quickly create fast and robust security scripts
 that utilize the powerful port scanning abilities of nmap.
 
-The latest version of this module can be found on here L<http://apersaud.github.com/Nmap-Parser/>
+The latest version of this module can be found on here L<https://modernistik.github.io/Nmap-Parser/>
 
 =head1 OVERVIEW
 
@@ -1163,7 +1164,7 @@ operating system signature information (OS guessed names, classes, osfamily..etc
   Nmap::Parser                        -- Core parser
      |
      +--Nmap::Parser::Session         -- Nmap scan session information
-     |  
+     |
      +--Nmap::Parser::Host            -- General host information
      |  |
      |  |-Nmap::Parser::Host::Service -- Port service information
@@ -1242,7 +1243,7 @@ you are parsing lots of nmap scan data files with persistent variables.
 Sets the parsing mode to be done using the callback function. It takes the parameter
 of a code reference or a reference to a function. If no code reference is given,
 it resets the mode to normal (no callback).
- 
+
  $np->callback(\&my_function); #sets callback, my_function() will be called
  $np->callback(); #resets it, no callback function called. Back to normal.
 
@@ -1407,7 +1408,7 @@ is used as the location in the array. The index starts at 0;
  hostname() eq hostname(0);
  hostname(1); #second hostname found
  hostname(400) eq hostname(1) #nothing at 400; return the name at the last index
- 
+
 
 =item B<ipv4_addr()>
 
@@ -1513,7 +1514,7 @@ a string argument can be given to these functions to filter the list.
 
  $host->tcp_ports('open') #returns all only 'open' ports (even 'open|filtered')
  $host->udp_ports('open|filtered'); #matches exactly ports with 'open|filtered'
- 
+
 I<Note that if a port state is set to 'open|filtered' (or any combination), it will
 be counted as an 'open' port as well as a 'filtered' one.>
 
@@ -1540,33 +1541,33 @@ Returns the state of the given port, provided by the port number in $portid.
 =item B<udp_open_ports()>
 
 Returns the list of open TCP|UDP ports respectively. Note that if a port state is
-for example, 'open|filtered', it will appear on this list as well. 
+for example, 'open|filtered', it will appear on this list as well.
 
 =item B<tcp_filtered_ports()>
 
 =item B<udp_filtered_ports()>
 
 Returns the list of filtered TCP|UDP ports respectively. Note that if a port state is
-for example, 'open|filtered', it will appear on this list as well. 
+for example, 'open|filtered', it will appear on this list as well.
 
 =item B<tcp_closed_ports()>
 
 =item B<udp_closed_ports()>
 
 Returns the list of closed TCP|UDP ports respectively. Note that if a port state is
-for example, 'closed|filtered', it will appear on this list as well. 
+for example, 'closed|filtered', it will appear on this list as well.
 
 =item B<tcp_service($portid)>
 
 =item B<udp_service($portid)>
 
 Returns the Nmap::Parser::Host::Service object of a given service running on port,
-provided by $portid. See Nmap::Parser::Host::Service for more info. 
+provided by $portid. See Nmap::Parser::Host::Service for more info.
 
  $svc = $host->tcp_service(80);
  $svc->name;
  $svc->proto;
- 
+
 
 =back
 
@@ -1624,7 +1625,7 @@ Returns the tunnel value. (If available)
 =item B<fingerprint()>
 
 Returns the service fingerprint. (If available)
- 
+
 =item B<version()>
 
 Returns the version of the given product of the running service.
@@ -1774,8 +1775,8 @@ The host name of this hop, if known.
 
 I think some of us best learn from examples. These are a couple of examples to help
 create custom security audit tools using some of the nice features
-of the Nmap::Parser module. Hopefully this can double as a tutorial. 
-More tutorials (articles) can be found at L<http://apersaud.github.com/Nmap-Parser/>
+of the Nmap::Parser module. Hopefully this can double as a tutorial.
+More tutorials (articles) can be found at L<https://modernistik.github.io/Nmap-Parser/>
 
 =head2 Real-Time Scanning
 
@@ -1803,7 +1804,7 @@ you can use cache_scan(). You must call cache_scan() BEFORE you initiate the par
  my $np = new Nmap::Parser;
 
  #telling np to save output
- $np->cache_scan('nmap.localhost.xml'); 
+ $np->cache_scan('nmap.localhost.xml');
  $np->parsescan('/usr/bin/nmap','-F','localhost');
  #do other stuff...
 
@@ -1821,9 +1822,9 @@ setup before parsing>
  use Nmap::Parser;
  my $np = new Nmap::Parser;
 
- 
+
  $np->callback( \&booyah );
- 
+
  $np->parsefile('nmap_results.xml');
     # or use parsescan()
 
@@ -1835,7 +1836,7 @@ setup before parsing>
     #when it returns, host object will be deleted from memory
     #(good for processing VERY LARGE files or scans)
  }
- 
+
 
 =head2 Multiple Instances - (C<no less 'of'; my $self>)
 
@@ -1852,30 +1853,30 @@ same hosts, and compare if any new tcp have been open since then
  use vars qw($nmap_exe $nmap_args @ips);
  my $base = new Nmap::Parser;
  my $curr = new Nmap::Parser;
- 
- 
+
+
  $base->parsefile('base_image.xml'); #load previous state
  $curr->parsescan($nmap_exe, $nmap_args, @ips); #scan current hosts
- 
- for my $ip ($curr->get_ips ) 
+
+ for my $ip ($curr->get_ips )
  {
  	#assume that IPs in base == IPs in curr scan
  	my $ip_base = $base->get_host($ip);
  	my $ip_curr = $curr->get_host($ip);
  	my %port = ();
- 	
+
  	#find ports that are open that were not open before
  	#by finding the difference in port lists
-	my @diff =  grep { $port{$_} < 2} 
-		   (map {$port{$_}++; $_} 
+	my @diff =  grep { $port{$_} < 2}
+		   (map {$port{$_}++; $_}
 		   ( $ip_curr->tcp_open_ports , $ip_base->tcp_open_ports ));
-	
+
 	print "$ip has these new ports open: ".join(',',@diff) if(scalar @diff);
-	
+
 	for (@diff){print "$_ seems to be ",$ip_curr->tcp_service($_)->name,"\n";}
- 		
+
  }
- 
+
 
 =head1 SUPPORT
 
@@ -1883,12 +1884,12 @@ same hosts, and compare if any new tcp have been open since then
 
 If you have questions about how to use the module, or any of its features, you
 can post messages to the Nmap::Parser module forum on CPAN::Forum.
-L<https://github.com/apersaud/Nmap-Parser/issues>
+L<https://github.com/modernistik/nmap-parser/issues>
 
 =head2 Bug Reports, Enhancements, Merge Requests
 
 Please submit any bugs or feature requests to:
-L<https://github.com/apersaud/Nmap-Parser/issues>
+L<https://github.com/modernistik/nmap-parser/issues>
 
 B<Please make sure that you submit the xml-output file of the scan which you are having
 trouble with.> This can be done by running your scan with the I<-oX filename.xml> nmap switch.
@@ -1898,17 +1899,17 @@ Please remove any important IP addresses for security reasons. It saves time in
 
  nmap, XML::Twig
 
-The Nmap::Parser page can be found at: L<http://apersaud.github.com/Nmap-Parser/>.
+The Nmap::Parser page can be found at: L<https://github.com/modernistik/nmap-parser>.
 It contains the latest developments on the module. The nmap security scanner
 homepage can be found at: L<http://www.insecure.org/nmap/>.
 
 =head1 AUTHORS
 
-Origiinal author, Anthony Persaud L<http://modernistik.com>. However, special thanks to: Daniel Miller L<https://github.com/bonsaiviking> and Robin Bowes L<http://robinbowes.com>.
+Origiinal author, Anthony Persaud L<https://www.modernistik.com>. However, special thanks to: Daniel Miller L<https://github.com/bonsaiviking> and Robin Bowes L<http://robinbowes.com>.
 Please see Changes file and CONTRIBUTORS file for a list of other great contributors.
 
 =head1 COPYRIGHT
-Copyright (c) <2003-2013> <Anthony Persaud> L<http://modernistik.com>
+Copyright (c) <2003-2013> <Anthony Persaud> L<https://www.modernistik.com>
 
 MIT License
 
